==> daktilo-0.3.1.tar.gz: daktilo-0.3.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [0.3.1] - 2023-10-10

### 📚 Documentation

- *(readme)* Add MacPorts install info ([#37](https://github.com/orhun/daktilo/pull/37)) - ([33ed3fd](https://github.com/orhun/daktilo/commit/33ed3fd874c76fd24ea59f4c3c5c91f8e64bfa59))

### ⚙️ Miscellaneous Tasks

- *(changelog)* Remove footer from changelog - ([c25044d](https://github.com/orhun/daktilo/commit/c25044d32291f472e1a7d7b988b6708e8cc27ee3))

## [0.3.0] - 2023-10-07

### 📇 Features

- *(playback)* Support selecting the output device - ([6bd8269](https://github.com/orhun/daktilo/commit/6bd8269639bd95f5a4386e32f9abc9adf15c12d1))

## [0.2.1] - 2023-10-05

### 🐛 Bug Fixes

- *(cd)* Use a custom token for triggering release workflow - ([0f8dcdc](https://github.com/orhun/daktilo/commit/0f8dcdcf2955577535bec8fa4da81bfca7aca7f5))

### 🚜 Refactor

- *(config)* Refactor preset selection logic - ([7f1e055](https://github.com/orhun/daktilo/commit/7f1e055dd91b9081cd5ffdc92889da8392caa630))

### 📚 Documentation

- *(readme)* Give more details about cargo ([#30](https://github.com/orhun/daktilo/pull/30)) - ([91c8e94](https://github.com/orhun/daktilo/commit/91c8e94567b942a37c32d21e141aa5d337c837fa))
- *(release)* Update release instructions - ([59101b5](https://github.com/orhun/daktilo/commit/59101b5aefa7eb788eb5aaa756f98012dd069eb6))
- *(security)* Update security policy for the new versions - ([73b12dc](https://github.com/orhun/daktilo/commit/73b12dcaeb07ab152593c8443ac3fc4f486fde5b))

## [0.2.0] - 2023-10-04

### 📇 Features

- *(cd)* Add continuous deployment workflow - ([eced001](https://github.com/orhun/daktilo/commit/eced001ef1d3df26305cbf69c1094a27e1d65feb))
- *(config)* Add drumkit preset ([#18](https://github.com/orhun/daktilo/pull/18)) - ([6899c65](https://github.com/orhun/daktilo/commit/6899c65778c14e0e10b9c1a62623273ea1e4a239))

### 📚 Documentation

- *(contributing)* Add 'how to add new presets' guide - ([00bc615](https://github.com/orhun/daktilo/commit/00bc61520f1b80ba52351d3aafbeb59d28013a08))
- *(readme)* Document linux dependencies ([#17](https://github.com/orhun/daktilo/pull/17)) - ([928f6ee](https://github.com/orhun/daktilo/commit/928f6ee1839dd34b29be0d1ae915eb01f48478f7))
- *(readme)* Use case sensitive regex in example ([#21](https://github.com/orhun/daktilo/pull/21)) - ([b296348](https://github.com/orhun/daktilo/commit/b29634867b1a4a45d654a93b47f6c6b7865ac52e))
- *(readme)* Add installation instructions for Alpine Linux - ([6935762](https://github.com/orhun/daktilo/commit/69357626c4f3c2aa69f22940ffda913adb18ff6a))
- *(readme)* Add supported platforms section - ([064c8ed](https://github.com/orhun/daktilo/commit/064c8ed409a07010fd38bc82aa75abff53a80774))
- *(readme)* Add similar projects section - ([84e5db1](https://github.com/orhun/daktilo/commit/84e5db122a60c0c95815e973a2c951a9774723ab))
- *(readme)* Add auxiliary explanation for the name of the app ([#13](https://github.com/orhun/daktilo/pull/13)) - ([187d616](https://github.com/orhun/daktilo/commit/187d616c0ce88aa24c2b5aa9c0603b38fb6852ce))
- *(readme)* Add instructions for installing on Arch Linux - ([02afb8a](https://github.com/orhun/daktilo/commit/02afb8a948d3641d856e607b34e5d869423c4c6c))

### ⚙️ Miscellaneous Tasks

- *(typos)* Add typos config - ([4de968d](https://github.com/orhun/daktilo/commit/4de968d4bbc19125e7a52668c98ec0e283e6c422))

<!-- generated by git-cliff -->

==> daktilo-0.4.0.tar.gz: daktilo-0.4.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## [0.4.0] - 2023-10-15

### 📇 Features

- *(playback)* Allow specifying multiple presets at once ([#43](https://github.com/orhun/daktilo/pull/43)) - ([4154b8c](https://github.com/orhun/daktilo/commit/4154b8c3dc69a0b210e29dbef64a3ddc3fcd4339))

## [0.3.1] - 2023-10-10

### 📚 Documentation

- *(readme)* Add MacPorts install info ([#37](https://github.com/orhun/daktilo/pull/37)) - ([33ed3fd](https://github.com/orhun/daktilo/commit/33ed3fd874c76fd24ea59f4c3c5c91f8e64bfa59))

### ⚙️ Miscellaneous Tasks

- *(changelog)* Remove footer from changelog - ([c25044d](https://github.com/orhun/daktilo/commit/c25044d32291f472e1a7d7b988b6708e8cc27ee3))

## [0.3.0] - 2023-10-07

### 📇 Features

- *(playback)* Support selecting the output device - ([6bd8269](https://github.com/orhun/daktilo/commit/6bd8269639bd95f5a4386e32f9abc9adf15c12d1))

## [0.2.1] - 2023-10-05

### 🐛 Bug Fixes

- *(cd)* Use a custom token for triggering release workflow - ([0f8dcdc](https://github.com/orhun/daktilo/commit/0f8dcdcf2955577535bec8fa4da81bfca7aca7f5))

### 🚜 Refactor

- *(config)* Refactor preset selection logic - ([7f1e055](https://github.com/orhun/daktilo/commit/7f1e055dd91b9081cd5ffdc92889da8392caa630))

### 📚 Documentation

- *(readme)* Give more details about cargo ([#30](https://github.com/orhun/daktilo/pull/30)) - ([91c8e94](https://github.com/orhun/daktilo/commit/91c8e94567b942a37c32d21e141aa5d337c837fa))
- *(release)* Update release instructions - ([59101b5](https://github.com/orhun/daktilo/commit/59101b5aefa7eb788eb5aaa756f98012dd069eb6))
- *(security)* Update security policy for the new versions - ([73b12dc](https://github.com/orhun/daktilo/commit/73b12dcaeb07ab152593c8443ac3fc4f486fde5b))

## [0.2.0] - 2023-10-04

### 📇 Features

- *(cd)* Add continuous deployment workflow - ([eced001](https://github.com/orhun/daktilo/commit/eced001ef1d3df26305cbf69c1094a27e1d65feb))
- *(config)* Add drumkit preset ([#18](https://github.com/orhun/daktilo/pull/18)) - ([6899c65](https://github.com/orhun/daktilo/commit/6899c65778c14e0e10b9c1a62623273ea1e4a239))

### 📚 Documentation

- *(contributing)* Add 'how to add new presets' guide - ([00bc615](https://github.com/orhun/daktilo/commit/00bc61520f1b80ba52351d3aafbeb59d28013a08))
- *(readme)* Document linux dependencies ([#17](https://github.com/orhun/daktilo/pull/17)) - ([928f6ee](https://github.com/orhun/daktilo/commit/928f6ee1839dd34b29be0d1ae915eb01f48478f7))
- *(readme)* Use case sensitive regex in example ([#21](https://github.com/orhun/daktilo/pull/21)) - ([b296348](https://github.com/orhun/daktilo/commit/b29634867b1a4a45d654a93b47f6c6b7865ac52e))
- *(readme)* Add installation instructions for Alpine Linux - ([6935762](https://github.com/orhun/daktilo/commit/69357626c4f3c2aa69f22940ffda913adb18ff6a))
- *(readme)* Add supported platforms section - ([064c8ed](https://github.com/orhun/daktilo/commit/064c8ed409a07010fd38bc82aa75abff53a80774))
- *(readme)* Add similar projects section - ([84e5db1](https://github.com/orhun/daktilo/commit/84e5db122a60c0c95815e973a2c951a9774723ab))
- *(readme)* Add auxiliary explanation for the name of the app ([#13](https://github.com/orhun/daktilo/pull/13)) - ([187d616](https://github.com/orhun/daktilo/commit/187d616c0ce88aa24c2b5aa9c0603b38fb6852ce))
- *(readme)* Add instructions for installing on Arch Linux - ([02afb8a](https://github.com/orhun/daktilo/commit/02afb8a948d3641d856e607b34e5d869423c4c6c))

### ⚙️ Miscellaneous Tasks

- *(typos)* Add typos config - ([4de968d](https://github.com/orhun/daktilo/commit/4de968d4bbc19125e7a52668c98ec0e283e6c422))

<!-- generated by git-cliff -->
